@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -22,9 +22,9 @@ from collections import OrderedDict
 from queue import Queue
 from threading import Thread
 
+import pyrogram
 from pyrogram.api import types
-from ..ext import utils
-from ..handlers import CallbackQueryHandler, MessageHandler, DeletedMessagesHandler, UserStatusHandler, RawUpdateHandler
+from ..handlers import CallbackQueryHandler, MessageHandler, RawUpdateHandler, UserStatusHandler, DeletedMessagesHandler
 
 log = logging.getLogger(__name__)
 
@@ -40,7 +40,7 @@ class Dispatcher:
         types.UpdateEditChannelMessage
     )
 
-    DELETE_MESSAGE_UPDATES = (
+    DELETE_MESSAGES_UPDATES = (
         types.UpdateDeleteMessages,
         types.UpdateDeleteChannelMessages
     )
@@ -62,16 +62,18 @@ class Dispatcher:
 
         self.update_parsers = {
             Dispatcher.MESSAGE_UPDATES:
-                lambda upd, usr, cht: (utils.parse_messages(self.client, upd.message, usr, cht), MessageHandler),
+                lambda upd, usr, cht: (pyrogram.Message._parse(self.client, upd.message, usr, cht), MessageHandler),
 
-            Dispatcher.DELETE_MESSAGE_UPDATES:
-                lambda upd, usr, cht: (utils.parse_deleted_messages(upd), DeletedMessagesHandler),
+            Dispatcher.DELETE_MESSAGES_UPDATES:
+                lambda upd, usr, cht: (pyrogram.Messages._parse_deleted(self.client, upd), DeletedMessagesHandler),
 
             Dispatcher.CALLBACK_QUERY_UPDATES:
-                lambda upd, usr, cht: (utils.parse_callback_query(self.client, upd, usr), CallbackQueryHandler),
+                lambda upd, usr, cht: (pyrogram.CallbackQuery._parse(self.client, upd, usr), CallbackQueryHandler),
 
             (types.UpdateUserStatus,):
-                lambda upd, usr, cht: (utils.parse_user_status(upd.status, upd.user_id), UserStatusHandler)
+                lambda upd, usr, cht: (
+                    pyrogram.UserStatus._parse(self.client, upd.status, upd.user_id), UserStatusHandler
+                )
         }
 
         self.update_parsers = {key: value for key_tuple, value in self.update_parsers.items() for key in key_tuple}
@@ -129,27 +131,32 @@ class Dispatcher:
                 if parser is None:
                     continue
 
-                update, handler_type = parser(update, users, chats)
+                parsed_update, handler_type = parser(update, users, chats)
 
                 for group in self.groups.values():
-                    for handler in group:
-                        args = None
+                    try:
+                        for handler in group:
+                            args = None
 
-                        if isinstance(handler, RawUpdateHandler):
-                            args = (update, users, chats)
-                        elif isinstance(handler, handler_type):
-                            if handler.check(update):
-                                args = (update,)
+                            if isinstance(handler, RawUpdateHandler):
+                                args = (update, users, chats)
+                            elif isinstance(handler, handler_type):
+                                if handler.check(parsed_update):
+                                    args = (parsed_update,)
 
-                        if args is None:
-                            continue
+                            if args is None:
+                                continue
+
+                            try:
+                                handler.callback(self.client, *args)
+                            except StopIteration:
+                                raise
+                            except Exception as e:
+                                log.error(e, exc_info=True)
 
-                        try:
-                            handler.callback(self.client, *args)
-                        except Exception as e:
-                            log.error(e, exc_info=True)
-                        finally:
                             break
+                    except StopIteration:
+                        break
             except Exception as e:
                 log.error(e, exc_info=True)
 
