@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -23,7 +23,6 @@ from .decorators import Decorators
 from .messages import Messages
 from .password import Password
 from .users import Users
-from .utilities import Utilities
 
 
 class Methods(
@@ -32,7 +31,6 @@ class Methods(
     Password,
     Chats,
     Users,
-    Utilities,
     Messages,
     Decorators
 ):
