@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -16,10 +16,13 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from pyrogram.api.core import Object
+import pyrogram
+
+from pyrogram.api import types
+from ..pyrogram_type import PyrogramType
 
 
-class Location(Object):
+class Location(PyrogramType):
     """This object represents a point on the map.
 
     Args:
@@ -30,8 +33,21 @@ class Location(Object):
             Latitude as defined by sender.
     """
 
-    ID = 0xb0700012
+    def __init__(self,
+                 *,
+                 client: "pyrogram.client.ext.BaseClient",
+                 longitude: float,
+                 latitude: float):
+        super().__init__(client)
 
-    def __init__(self, longitude: float, latitude: float):
         self.longitude = longitude
         self.latitude = latitude
+
+    @staticmethod
+    def _parse(client, geo_point: types.GeoPoint) -> "Location":
+        if isinstance(geo_point, types.GeoPoint):
+            return Location(
+                longitude=geo_point.long,
+                latitude=geo_point.lat,
+                client=client
+            )
